@setlocal
@ECHO OFF
REM *********************************************************************
REM TDMGPP.BAT -> create Windows GUI, CON, OBJ or DLL using TDM-GCC g++
REM For use with TDM-GCC 4.8.1 and greater
REM uses -std=gnu++11 for C++11 with gnu extensions
REM 
REM *********************************************************************
REM Parameter 1 source file name no extension
REM Parameter 2 should be -m32 -m64
REM Parameter 3 should be CON for console GUI for windows OBJ for object and DLL dll for ...
REM *********************************************************************
REM Note: Removed -O2 
REM Note: Added it back
REM *********************************************************************

REM IF[%1]==[] GOTO usage
REM get just file name. RadAsm3 passes complete path with non project files
REM ********************************************************************* 
REM ----------------------------
SET F=%~nx1
REM ----------------------------

IF [%2] == [] GOTO usage
IF [%3] == []   GOTO usage

REM SET STATICLIB=-static-libgcc --std=gnu11
SET STATICLIB=-static-libgcc -std=c++14

IF /I [%3] == [CON] (
  REM SET GCCCFL= --std=gnu++11  -pipe -mconsole %2 -s -O2 -D_WIN32_IE=0x0501
  SET GCCCFL= -std=c++14  -pipe -mconsole %2 -s -O2 -D_WIN32_IE=0x0501
  SET FTYPE="Windows Console App"
  SET OUTFILE="%F%.EXE"
)

IF /I [%3] == [GUI] (
  REM SET GCCCFL= --std=gnu++11 -pipe -mwindows %2 -s -O2 -D_WIN32_IE=0x0501
  SET GCCCFL= -std=c++14 -pipe -mwindows %2 -s -O2 -D_WIN32_IE=0x0501
  SET FTYPE="Windows Gui App"
  SET OUTFILE="%F%.EXE"
)

IF /I [%3] == [DLL] (
  REM SET GCCCFL= -D_WIN32_IE=0x0501 --std=gnu++11  -pipe -shared -s -O2 %2 -Wl,--add-stdcall-alias,--output-def,"%F%.def",--out-implib,"lib%F%.a"
  SET GCCCFL= -D_WIN32_IE=0x0501 -std=c++14  -pipe -shared -s -O2 %2 -Wl,--add-stdcall-alias,--output-def,"%F%.def",--out-implib,"lib%F%.a"
  SET FTYPE="Windows Dll"
  SET OUTFILE="%F%.DLL"
)

IF /I [%3] == [OBJ] (
    SET GCCCFL=OBJ
)

IF /I [%3] == [LIB] (
    SET GCCCFL=LIB
)
IF NOT DEFINED GCCCFL GOTO usage
IF NOT EXIST "%F%.cpp" GOTO usage
REM --------------------------------------------------------------------
REM MINGW is set in RadAsm3 Environment Options
REM --------------------------------------------------------------------
REM SET var=%cd%
REM CD /D %MINGW%
REM IF EXIST "set_distro_paths.bat" CALL set_distro_paths
REM CD /D %var%

SET PATH=%MINGW%\bin;%PATH%
SET INCLUDE=%MINGW%\include;%MINGW%\include\sys;%INCLUDE%
SET LIB=%MINGW%\lib

REM NOTE: WIN_VER is set in bc9Ed Menu -> Options -> Environment

IF /I [%3] == [OBJ] (
  g++ -c %2 %F%.cpp %WIN_VER% -D_WIN32_IE=0x0501 %4 %5 %6 %7 %8 %9
GOTO done
)

IF /I [%3] == [LIB] (
  g++ -c %2 %F%.cpp %WIN_VER% -D_WIN32_IE=0x0501 %4 %5 %6 %7 %8 %9
  ar rcs lib%F%.a %F%.o
  GOTO done
)

SET LIBS=-lmingw32 -lgcc -lkernel32 -luser32 -lgdi32 -lcomctl32 -ladvapi32 -lwinspool -lshell32 -lole32 -loleaut32 -luuid -lodbc32 -lodbccp32 -lwinmm -lcomdlg32 -limagehlp -lversion -lwininet -lurlmon %LIBS%

REM set 32/64 bit resource target

IF [%2] == [-m32] (
SET RESTARGET=-Fpe-i386
)

REM --------------------------------------------------------------
REM always use the %F%.rc file in the Res Directory if it exists
REM this should handle both projects and individual files with resources

IF EXIST "res\%F%.rc" (
  ECHO Compiling resources.....
  cd res
  windres -I. %WIN_VER% %RESTARGET% -i "%F%.rc" -o "%F%res.o"
  SET GRES="res\%F%res.o"
  cd ..
) ELSE (
  IF EXIST "%F%.rc" (
    ECHO Compiling resources.....
    windres -I. %WIN_VER% %RESTARGET% -i "%F%.rc" -o "%F%res.o"
    SET GRES="%F%res.o"
  )
)
REM --------------------------------------------------------------



IF /I [%2] == [-m32] SET MACH=32bit
IF /I [%2] == [-m64] SET MACH=64bit
ECHO Compiling "%F%.cpp" to a %MACH% %FTYPE% Using the TDM-GCC Distro

REM IF /I [%3] == [DLL] (
REM   g++ %GCCCFL% "%F%.cpp" %WIN_VER% -o"%F%.dll" %GRES%  -static %4 %5 %6 %7 %8 %9 %LIBS%
REM ) ELSE (
  g++ %WARN% %GCCCFL% "%F%.cpp" %WIN_VER% -o %OUTFILE% %GRES%  -static  %4 %5 %6 %7 %8 %9 %LIBS%
REM )



ECHO Finished!
IF EXIST "%GRES%" del "%GRES%"
IF EXIST "%F%.o" del "%F%.o"
IF EXIST libs.bat del libs.bat
GOTO done
:usage
ECHO **************************************************************
ECHO  Usage:  TDMGPP.BAT MainFile  -m32 or-m64 [CON GUI DLL OBJ] ExtraFile1 ExtraFile2
ECHO  Note:   ExtraFiles can be .a (import or static libraries) and
ECHO          .o (objectfiles)
ECHO     Use this batch file to easily create your g++ program
ECHO **************************************************************
:done
endlocal
