
@setlocal enableextensions enabledelayedexpansion

@ECHO OFF
REM Note that this bat will compile either .cpp or .c sources.
REM it checks for .cpp first and if you happen to have a .cpp file even though you want
REM .c the .cpp will be used. Delete a .cpp before you translate to a .c source

REM get just file name. RadAsm3 passes complete path with non project files
REM Note: because FN is set using %F% with quotes no need for quoted %FN%
REM ----------------------------
 SET F=%~nx1
REM ----------------------------
REM See if we have a .cpp source
IF EXIST "%F%.cpp" (
  SET FN="%F%.cpp"
  SET CFIX=0
  GOTO start
)
GOTO usage
REM NO .cpp? check for a .c
REM IF NOT EXIST "%F%.c" GOTO usage
REM SET FN="%F%.c"
REM For use with InsertOptArg below (bc9Basic)
REM SET CFIX=1

:start

IF [%2]==[] GOTO usage
IF [%3]==[] GOTO usage

REM param 4 -> Debug or Release

SET BUILD=%4
REM IF [%BUILD%]==[] SET BUILD=Release
IF [%BUILD%]==[] (
  SET BUILD=/MT
  GOTO gotbuild
)

IF /I [%4] == [debug] (
  SET BUILD=/MTd
  GOTO gotbuild
)

IF /I [%4] == [release] SET BUILD=/MT

:gotbuild

IF /I [%2] == [-m32] (
  SET XTYPE=x86
  GOTO gotit
)
IF /I [%2] == [-m64] (
  SET XTYPE=x86_amd64
)

:gotit

REM these next check for command line defines in the format /DMYEQUATE:1
REM you cannot use an "=" in batch files.  ":" is substituted and changed to =

IF [%5]==[] GOTO setup
  SET P5=%5
  SET STR1=%5
  IF NOT X%STR1:/D=%==X%STR1% (
    SET P5=%STR1::==%
    SET STR1=
  ) 

IF [%6]==[] GOTO setup
  SET P6=%6
  SET STR1=%6
  IF NOT X%STR1:/D=%==X%STR1% (
    SET P6=%STR1::==%
    SET STR1=
  ) 

IF [%7]==[] GOTO setup
  SET P7=%7
  SET STR1=%7
  IF NOT X%STR1:/D=%==X%STR1% (
    SET P7=%STR1::==%
    SET STR1=
  ) 

IF [%8]==[] GOTO setup
  SET P8=%8
  SET STR1=%8
  IF NOT X%STR1:/D=%==X%STR1% (
    SET P8=%STR1::==%
    SET STR1=
  ) 


:setup

IF DEFINED VS140COMNTOOLS (
  CALL "%VS140COMNTOOLS%..\..\VC\vcvarsall.bat" %XTYPE%
  GOTO got_tools
)

IF DEFINED VS120COMNTOOLS (
  CALL "%VS120COMNTOOLS%..\..\VC\vcvarsall.bat" %XTYPE%
  GOTO got_tools
)

IF DEFINED VS110COMNTOOLS (
  CALL "%VS110COMNTOOLS%..\..\VC\vcvarsall.bat" %XTYPE%
  GOTO got_tools
)

IF DEFINED VS100COMNTOOLS (
  CALL "%VS100COMNTOOLS%..\..\VC\vcvarsall.bat" %XTYPE%
  GOTO got_tools
)


:got_tools

IF "%WARN%"=="" SET WARN=/W1

REM do the setup for paths and 32/64
REM CALL "%COMNTOOLS%..\..\VC\vcvarsall.bat" %XTYPE%
REM SET INCLUDE=C:\VS1264\boost_1_55_0;%INCLUDE%
REM SET LIB=C:\VS1264\boost_1_55_0\lib64-msvc-12.0;%LIB%

IF /I [%3] == [CON] (
  SET SUBSYS= /SUBSYSTEM:CONSOLE
  SET FTYPE="Windows Console App"
)

IF /I [%3] == [GUI] (
  SET SUBSYS=/SUBSYSTEM:WINDOWS
  SET FTYPE="Windows Gui App"
)

IF /I [%3] == [DLL] (
  SET SUBSYS=/DLL
  SET FTYPE="a Windows DLL"
)

IF /I [%3] == [OBJ] (
  SET SUBSYS=/DLL
  SET FTYPE="a Windows Object File"
)

IF /I [%3] == [LIB] (
  SET SUBSYS=/DLL
  SET FTYPE="a Windows Static Library File"
)

REM --------------------------------------------------------------
REM always use the %F%.rc file in the Res Directory if it exists
REM this should handle both projects and individual files with resources

IF EXIST "res\%F%.rc" (
  ECHO Compiling resources.....
  cd res
  Rc "%F%"
  SET VRES="res\%F%.res"
  cd ..
) ELSE (
  IF EXIST "%F%.rc" (
    ECHO Compiling resources.....
    Rc "%F%"
    SET VRES="%F%.res"
  )
)
REM For use with bc9Basic
REM Insert optional arguments for "c" source
IF [%CFIX%]==[1] (
InsertOptArg %FN% -vc
)
REM --------------------------------------------------------------
ECHO Compiling %FN% To a %FTYPE%
REM the first compile/link creates a .def file which we use in a
REM  second call to add undecorated function names to the dll.
IF /I [%3]==[DLL] (
  cl.exe  %FN% %VRES% /EHsc /D %BUILD% /link /DLL /OUT:"%F%.dll"
  REM add undecorated function names to the dll only on 32 bit
  IF /I [%XTYPE%]==[x86] (
    IF EXIST "%F%.def" (
      cl.exe /LD "%F%.obj" %VRES% "%F%.def"
    )
  )
  GOTO cleanup
)

IF /I [%3]==[OBJ] (
  cl.exe  /c /O1 /Gd %WARN% /EHsc %BUILD% %FN% %WIN_VER% %P5% %P6% %P7% %P8%
  GOTO cleanup
)
IF /I [%3]==[LIB] (
  cl.exe  /c /O1 /Gd %WARN% /EHsc %BUILD% %FN% %WIN_VER% %P5% %P6% %P7% %P8%
  lib.exe %F%.obj
  GOTO cleanup
)

REM Console and gui
REM cl.exe  /O1 /Gd /W1 /EHsc %BUILD%  %FN% /Fe"%F%.EXE" %WIN_VER% %VRES%  /link %SUBSYS% %5 %6 %7 %8
cl.exe  /O1 /Gd %WARN% /EHsc /MT  %FN% /Fe"%F%.EXE" %WIN_VER% %VRES% %SUBSYSTEM% %P5% %P6% %P7% %P8%
:cleanup
ECHO Finished!
IF /I NOT [%3]==[OBJ] (
  IF EXIST "%F%.obj" del "%F%.obj"
)
IF EXIST "%F%.res" del "%F%.res"
GOTO done
:usage
ECHO **************************************************************
ECHO  Usage:  VS12.BAT MainFile  [-m32  -m64] [con  gui  dll obj] extra files
ECHO  Note:   ExtraFiles can be .libs, .res , .obj
ECHO **************************************************************
:done
endlocal
